@@ -6,6 +6,7 @@ from pyspark.sql.functions import col, filter
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -44,22 +45,25 @@ def test_auto_mapper_columns(spark_session: SparkSession) -> None:
 
     # Assert
     assert len(sql_expressions) == 4
-    assert str(sql_expressions["dst1"]) == str(lit("src1").alias("dst1"))
-    assert str(sql_expressions["dst2"]) == str(
-        filter(array(lit("address1")), lambda x: x.isNotNull()).alias("dst2")
+    assert_expressions_are_equal(sql_expressions["dst1"], lit("src1").alias("dst1"))
+    assert_expressions_are_equal(
+        sql_expressions["dst2"],
+        filter(array(lit("address1")), lambda x: x.isNotNull()).alias("dst2"),
     )
-    assert str(sql_expressions["dst3"]) == str(
+    assert_expressions_are_equal(
+        sql_expressions["dst3"],
         filter(array(lit("address1"), lit("address2")), lambda x: x.isNotNull()).alias(
             "dst3"
-        )
+        ),
     )
-    assert str(sql_expressions["dst4"]) == str(
+    assert_expressions_are_equal(
+        sql_expressions["dst4"],
         filter(
             array(
                 struct(lit("usual").alias("use"), col("b.last_name").alias("family"))
             ),
             lambda x: x.isNotNull(),
-        ).alias("dst4")
+        ).alias("dst4"),
     )
 
     result_df: DataFrame = mapper.transform(df=df)
