@@ -1,14 +1,18 @@
 from typing import Dict, Optional, Union
 
 from pyspark.sql import SparkSession, Column, DataFrame
+
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import col
 from pyspark.sql.types import StructType, StructField, StringType, LongType, DataType
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.data_types.complex.complex_base import AutoMapperDataTypeComplexBase
+from spark_auto_mapper.data_types.complex.complex_base import (
+    AutoMapperDataTypeComplexBase,
+)
 from spark_auto_mapper.data_types.number import AutoMapperNumberDataType
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -30,15 +34,14 @@ class MyClass(AutoMapperDataTypeComplexBase):
         return schema
 
 
-def test_auto_mapper_complex_with_defined_class(
-    spark_session: SparkSession
-) -> None:
+def test_auto_mapper_complex_with_defined_class(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran', 45),
-            (2, 'Vidal', 'Michael', 35),
-        ], ['member_id', 'last_name', 'first_name', 'my_age']
+            (1, "Qureshi", "Imran", 45),
+            (2, "Vidal", "Michael", 35),
+        ],
+        ["member_id", "last_name", "first_name", "my_age"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -51,30 +54,27 @@ def test_auto_mapper_complex_with_defined_class(
         view="members",
         source_view="patients",
         keys=["member_id"],
-        drop_key_columns=False
-    ).complex(
-        MyClass(name=A.column("last_name"), age=A.number(A.column("my_age")))
-    )
+        drop_key_columns=False,
+    ).complex(MyClass(name=A.column("last_name"), age=A.number(A.column("my_age"))))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
     result_df: DataFrame = mapper.transform(df=df)
 
     # Assert
-    assert str(sql_expressions["name"]
-               ) == str(col("b.last_name").cast("string").alias("name"))
-    assert str(sql_expressions["age"]
-               ) == str(col("b.my_age").cast("long").alias("age"))
+    assert_expressions_are_equal(
+        sql_expressions["name"], col("b.last_name").cast("string").alias("name")
+    )
+    assert_expressions_are_equal(
+        sql_expressions["age"], col("b.my_age").cast("long").alias("age")
+    )
 
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1"
-                           ).select("name").collect()[0][0] == "Qureshi"
+    assert result_df.where("member_id == 1").select("name").collect()[0][0] == "Qureshi"
 
     assert dict(result_df.dtypes)["age"] in ("int", "long", "bigint")
