@@ -2,6 +2,8 @@ from pathlib import Path
 from typing import Dict
 
 from pyspark.sql import SparkSession, DataFrame, Column
+
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from tests.conftest import clean_spark_session
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
@@ -31,8 +33,9 @@ def test_automapper_concat_array(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) == str(
-        concat(col("b.identifier"), array(lit("foo").cast("string"))).alias("age")
+    assert_expressions_are_equal(
+        sql_expressions["age"],
+        concat(col("b.identifier"), array(lit("foo").cast("string"))).alias("age"),
     )
     result_df: DataFrame = mapper.transform(df=source_df)
 
