@@ -8,6 +8,7 @@ from pyspark.sql.functions import col
 from pyspark.sql.functions import coalesce, to_date
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -36,12 +37,13 @@ def test_auto_mapper_date_column(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["birthDate"]) == str(
+    assert_expressions_are_equal(
+        sql_expressions["birthDate"],
         coalesce(
             to_date(col("b.date_of_birth"), format="y-M-d"),
             to_date(col("b.date_of_birth"), format="yyyyMMdd"),
             to_date(col("b.date_of_birth"), format="M/d/y"),
-        ).alias("birthDate")
+        ).alias("birthDate"),
     )
 
     result_df: DataFrame = mapper.transform(df=df)
