@@ -4,6 +4,7 @@ from typing import Dict
 from pyspark.sql import SparkSession, DataFrame, Column
 from pyspark.sql.functions import filter
 
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from tests.conftest import clean_spark_session
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
@@ -35,8 +36,9 @@ def test_automapper_filter(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) == str(
-        filter("b.identifier", lambda x: x["use"] == lit("usual")).alias("age")
+    assert_expressions_are_equal(
+        sql_expressions["age"],
+        filter("b.identifier", lambda x: x["use"] == lit("usual")).alias("age"),
     )
     result_df: DataFrame = mapper.transform(df=source_df)
 
