@@ -2,10 +2,13 @@ from pathlib import Path
 from typing import Dict
 
 from pyspark.sql import SparkSession, DataFrame, Column
+
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from tests.conftest import clean_spark_session
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import col
 
@@ -16,9 +19,7 @@ def test_automapper_first(spark_session: SparkSession) -> None:
 
     data_json_file: Path = data_dir.joinpath("data.json")
 
-    source_df: DataFrame = spark_session.read.json(
-        str(data_json_file), multiLine=True
-    )
+    source_df: DataFrame = spark_session.read.json(str(data_json_file), multiLine=True)
 
     source_df.createOrReplaceTempView("patients")
 
@@ -30,14 +31,13 @@ def test_automapper_first(spark_session: SparkSession) -> None:
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]
-               ) == str(col("b.identifier[0]").alias("age"))
+    assert_expressions_are_equal(
+        sql_expressions["age"], col("b.identifier[0]").alias("age")
+    )
     result_df: DataFrame = mapper.transform(df=source_df)
 
     result_df.show(truncate=False)
