@@ -6,6 +6,7 @@ from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import col
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -57,8 +58,8 @@ def test_automapper_first_valid_column(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) == str(
-        col("my_age").cast("long").cast("long").alias("age")
+    assert_expressions_are_equal(
+        sql_expressions["age"], col("my_age").cast("long").cast("long").alias("age")
     )
     result_df: DataFrame = mapper.transform(df=df)
 
