@@ -7,6 +7,7 @@ from pyspark.sql.functions import array_join
 from pyspark.sql.functions import col
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -34,8 +35,9 @@ def test_auto_mapper_join_using_delimiter(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["my_column"]) == str(
-        array_join(col("b.suffix"), ", ").alias("my_column")
+    assert_expressions_are_equal(
+        sql_expressions["my_column"],
+        array_join(col("b.suffix"), ", ").alias("my_column"),
     )
 
     result_df: DataFrame = mapper.transform(df=df)
