@@ -2,6 +2,7 @@ from typing import Dict
 
 from pyspark.sql.functions import lpad, col
 
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 from pyspark.sql import SparkSession, DataFrame, Column
@@ -34,8 +35,9 @@ def test_auto_mapper_lpad(spark_session: SparkSession) -> None:
     assert isinstance(mapper, AutoMapper)
     sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
 
-    assert str(sql_expressions["my_column"]) == str(
-        lpad(col=col("b.empi"), len=9, pad="0").alias("my_column")
+    assert_expressions_are_equal(
+        sql_expressions["my_column"],
+        lpad(col=col("b.empi"), len=9, pad="0").alias("my_column"),
     )
 
     result_df: DataFrame = mapper.transform(df=df)
