@@ -7,6 +7,7 @@ from pyspark.sql.functions import col, lit
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -34,23 +35,21 @@ def test_auto_mapper_number(spark_session: SparkSession) -> None:
         drop_key_columns=False,
     ).columns(
         age=A.number(A.column("my_age")),
-        null_field=A.number(AutoMapperDataTypeLiteral(None))
+        null_field=A.number(AutoMapperDataTypeLiteral(None)),
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) in (
-        str(col("b.my_age").cast("int").alias("age")),
-        str(col("b.my_age").cast("long").alias("age")),
+    assert_expressions_are_equal(
+        sql_expressions["age"], col("b.my_age").cast("long").alias("age")
     )
 
-    assert str(sql_expressions["null_field"]
-               ) == str(lit(None).cast("long").alias("null_field"))
+    assert_expressions_are_equal(
+        sql_expressions["null_field"], lit(None).cast("long").alias("null_field")
+    )
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -58,15 +57,13 @@ def test_auto_mapper_number(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select("age"
-                                                    ).collect()[0][0] == 54
-    assert result_df.where("member_id == 2").select("age"
-                                                    ).collect()[0][0] == 67
+    assert result_df.where("member_id == 1").select("age").collect()[0][0] == 54
+    assert result_df.where("member_id == 2").select("age").collect()[0][0] == 67
     assert (
-        result_df.where("member_id == 3").select("age").collect()[0][0] ==
-        131026061001
+        result_df.where("member_id == 3").select("age").collect()[0][0] == 131026061001
+    )
+    assert (
+        result_df.where("member_id == 1").select("null_field").collect()[0][0] is None
     )
-    assert result_df.where("member_id == 1").select("null_field"
-                                                    ).collect()[0][0] is None
 
     assert dict(result_df.dtypes)["age"] in ("int", "long", "bigint")
