@@ -1,10 +1,12 @@
 from typing import Dict
 
 from pyspark.sql import SparkSession, Column, DataFrame
+
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import col
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -12,9 +14,10 @@ def test_auto_mapper_number_typed(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran', "54"),
-            (2, 'Vidal', 'Michael', "67"),
-        ], ['member_id', 'last_name', 'first_name', "my_age"]
+            (1, "Qureshi", "Imran", "54"),
+            (2, "Vidal", "Michael", "67"),
+        ],
+        ["member_id", "last_name", "first_name", "my_age"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -30,13 +33,11 @@ def test_auto_mapper_number_typed(spark_session: SparkSession) -> None:
     ).columns(age=A.number(A.column("my_age")))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) == str(col("b.my_age").alias("age"))
+    assert_expressions_are_equal(sql_expressions["age"], col("b.my_age").alias("age"))
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -44,9 +45,7 @@ def test_auto_mapper_number_typed(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select("age"
-                                                    ).collect()[0][0] == 54
-    assert result_df.where("member_id == 2").select("age"
-                                                    ).collect()[0][0] == 67
+    assert result_df.where("member_id == 1").select("age").collect()[0][0] == 54
+    assert result_df.where("member_id == 2").select("age").collect()[0][0] == 67
 
     assert dict(result_df.dtypes)["age"] in ("int", "long", "bigint")
