@@ -4,6 +4,7 @@ from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import expr, struct
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -11,9 +12,10 @@ def test_auto_mapper_struct_with_mappers(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran'),
-            (2, 'Vidal', 'Michael'),
-        ], ['member_id', 'last_name', 'first_name']
+            (1, "Qureshi", "Imran"),
+            (2, "Vidal", "Michael"),
+        ],
+        ["member_id", "last_name", "first_name"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -26,24 +28,23 @@ def test_auto_mapper_struct_with_mappers(spark_session: SparkSession) -> None:
         view="members",
         source_view="patients",
         keys=["member_id"],
-        drop_key_columns=False
+        drop_key_columns=False,
     ).columns(dst2=A.complex(use="usual", family=A.struct({"given": "foo"})))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
     result_df: DataFrame = mapper.transform(df=df)
 
     # Assert
-    assert str(sql_expressions["dst2"]) == str(
+    assert_expressions_are_equal(
+        sql_expressions["dst2"],
         struct(
             expr("usual").alias("use"),
-            struct(expr("foo").alias("given")).alias("family")
-        ).alias("dst2")
+            struct(expr("foo").alias("given")).alias("family"),
+        ).alias("dst2"),
     )
 
     result_df.printSchema()
