@@ -6,6 +6,7 @@ from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import col
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -34,7 +35,9 @@ def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["lname"]) == str(col("b.last_name").alias("lname"))
+    assert_expressions_are_equal(
+        sql_expressions["lname"], col("b.last_name").alias("lname")
+    )
 
     result_df: DataFrame = mapper.transform(df=df)
 
